<?php
/**
 * Set pets layout according to options
 *
 * @package Pets
 */

defined( 'WPINC' ) || exit;

/**
 * Layout manager.
 */
class Pets_Layout extends Pets_Base {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'pets_before_wrapper', 'add_header' );
		$this->add_action( 'pets_single_post_header_thumb', 'single_post_header_thumb' );
		$this->add_action( 'pets_before_content', 'pages_title_section' );
	}

	/**
	 * Add header
	 */
	public function add_header() {
		$hash   = array(
			'header-default' => 'default',
			'header-layout2' => 'layout2',
		);
		$layout = pets_get_settings( 'header_styles' );
		get_template_part( 'template-parts/header/header', isset( $hash[ $layout ] ) ? $hash[ $layout ] : $layout );
	}

	/**
	 * Single post header thumbnail
	 */
	public function single_post_header_thumb() {

		if ( pets_get_settings( 'show_single_featured' ) ) {
			echo '<div class="single-featured-wrap">';
			the_post_thumbnail( 'pets-featured', array( 'class' => 'single-featured-image' ) );
			echo '</div>';
		}

	}

	/**
	 * Pages Title Section
	 */
	function pages_title_section() {

		$header_animation = pets_get_post_header_effect();

		if ( ( is_page() || is_single() ) && has_post_thumbnail() && ( 'parallax' === $header_animation || 'zoomout' === $header_animation ) ) {

			pets_single_featured_image_effect();

			echo '<div class="container">';
				echo '<div class="breadcrumb-wrapper">';
					pets_breadcrumbs();
				echo '</div>';
			echo '</div>';

			return;
		}

		if ( pets_get_settings( 'show_pages_title' ) ) :
			?>
			<div class="pages-title-section">

				<div class="container clearfix">

				<?php

				$pages_title = pets_get_settings( 'pages_title' );

				if ( $pages_title && ( is_front_page() || is_home() || is_single() ) ) {
					if ( function_exists( 'is_woocommerce' ) && is_woocommerce() && is_product() ) {
					?>
						<h1><?php woocommerce_page_title(); ?></h1>
					<?php
					} else {
						echo '<h1>' . $pages_title . '</h1>';
					}
				} elseif ( is_archive() ) {
					the_archive_title( '<h1>', '</h1>' );
				} elseif ( is_search() ) {
				?>
					<h1><?php echo esc_html__( 'Search', 'pets' ); ?></h1>
				<?php
				} elseif ( is_page() ) {
				?>
					<h1 class="title entry-title"><?php the_title(); ?></h1>
				<?php
				} elseif ( is_404() ) {
				?>
					<h1 class="page-title"><?php echo esc_html_e( '404 Not Found', 'pets' ); ?></h1>
				<?php
				} elseif ( pets_is_woocommerce_active() ) {
					if ( is_shop() || is_product_taxonomy() ) {
					?>
						<h1><?php woocommerce_page_title(); ?></h1>
					<?php
					}
					if ( is_product() || is_cart() || is_checkout() || is_account_page() ) {
					?>
						<h1 class="page-title"><?php the_title(); ?></h1>
					<?php
					}
				}

				if ( is_home() ) {
				?>
				<div class="back-to-home">
					<a href="<?php echo esc_url( trailingslashit( home_url() ) ); ?>"><?php _e( 'Back to home', 'pets' ); ?></a>
				</div>
				<?php
				}
				if ( ! is_home() && ! is_archive() && ! is_404() ) {
					pets_breadcrumbs();
				}
				?>

				</div><!-- end of .container -->

			</div>
			<?php
		endif;

	}

}

// Init.
new Pets_Layout;
