<?php
/**
 * HomePage Posts
 *
 * @package Pets
 */

$features = pets_get_settings( 'featured_categories' );
if ( empty( $features ) ) {
	return;
}
foreach ( $features as $feature ) :
	$title        = isset( $feature['mts_featured_title'] ) ? $feature['mts_featured_title'] : 'No Title';
	$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : '';
	if ( 'layout-default' === $posts_layout ) {
		$posts_layout = 'default';
	}
	$unique_id = isset( $feature['unique_id'] ) ? $feature['unique_id'] : '';

	$menus['blog']['child'][ 'blog-' . $unique_id ] = array(
		'title' => $title,
		// translators: description.
		'desc'  => sprintf( wp_kses_post( __( 'From here, you can control the elements of %s', 'pets' ) ), $title ),
	);

	// Dependency check that back to top option is enable.
	$post_title_dependency = array(
		'relation' => 'and',
		array(
			'field'      => 'featured_category_title_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		),
	);

	$sections[ 'blog-' . $unique_id ] = array(

		/**
		 * Layout Default Settings
		 *
		 * @package Pets
		 */

		// Section Title.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'pets' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'pets' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'pets' ),
			'std'      => '0',
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'pets' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'pets' ),
			'options'    => array(
				'left'   => esc_html__( 'Left', 'pets' ),
				'center' => esc_html__( 'Center', 'pets' ),
				'right'  => esc_html__( 'Right', 'pets' ),
			),
			'std'        => 'left',
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'pets' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'pets' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'pets' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'pets' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '40px',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'pets' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'pets' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'pets' ),
			'sub_desc'   => esc_html__( 'Select border', 'pets' ),
			'dependency' => $post_title_dependency,
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'pets' ),
			'std'        => array(
				'preview-text'  => 'Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Muli',
				'font-weight'   => '700',
				'font-size'     => '22px',
				'color'         => '#566073',
				'css-selectors' => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => $post_title_dependency,
		) : null,

		// Author Info.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'author_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Author Meta Info', 'pets' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'show_author_meta_info_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Author Meta Info', 'pets' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide Author Meta Info.', 'pets' ),
			'std'      => '1',
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'author_meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Author Meta Info Font', 'pets' ),
			'std'   => array(
				'preview-text'  => 'Author Meta Info',
				'preview-color' => 'light',
				'font-family'   => 'Muli',
				'font-weight'   => '700',
				'font-size'     => '18px',
				'color'         => '#566073',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .author-meta-info, .layout-' . $unique_id . ' .latestPost .author-meta-info a',
			),
		) : null,

		// Meta info.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'pets' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'pets' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'pets' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'date'    => array(
						'label'     => esc_html__( 'Date', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
					'time'    => array(
						'label'     => __( 'Reading Time', 'pets' ),
						'subfields' => array(
							array(
								'id'       => 'mts_meta_info_time_icon_' . $unique_id,
								'type'     => 'icon_select',
								'title'    => esc_html__( 'Select Icon', 'pets' ),
								// translators: link to plugin.
								'sub_desc' => sprintf( wp_kses_post( __( 'Need Time to Read plugin for this option. <a href="%s">Click here</a> to install it.', 'pets' ) ), 'https://mythemeshop.com/plugins/wp-time-to-read/' ),
							),
						),
					),
				),
				'disabled' => array(
					'category' => array(
						'label'     => esc_html__( 'Categories', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(
					'date'    => array(
						'label'     => esc_html__( 'Date', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
					'time'    => array(
						'label'     => __( 'Reading Time', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_time_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
				),
				'disabled' => array(
					'category' => array(
						'label'     => esc_html__( 'Categories', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
				),
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'meta_info_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'pets' ),
			'sub_desc' => esc_html__( 'Select border.', 'pets' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'pets' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Muli',
				'font-weight'    => '700',
				'font-size'      => '14px',
				'color'          => '#566073',
				'additional-css' => 'text-transform: uppercase; letter-spacing: 0.504px;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			),
		) : null,
		// Post Container.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'pets' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'pets' ),
			'sub_desc' => esc_html__( 'Select border', 'pets' ),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'pets' ),
			'sub_desc' => esc_html__( 'Post margin.', 'pets' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => '0',
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'pets' ),
			'sub_desc' => esc_html__( 'Post padding.', 'pets' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'pets' ),
			'std'   => array(
				'preview-text'  => 'Post Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Muli',
				'font-weight'   => '700',
				'font-size'     => '32px',
				'line-height'   => '40px',
				'color'         => '#566073',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'pets' ),
			'std'   => array(
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Muli',
				'font-weight'   => '300',
				'font-size'     => '16px',
				'line-height'   => '26px',
				'color'         => '#566073',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
		) : null,

		/**
		 * Layout 1 Settings
		 *
		 * @package Pets
		 */

		// Section Title.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'pets' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'pets' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'pets' ),
			'std'      => '0',
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'pets' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'pets' ),
			'options'    => array(
				'left'   => esc_html__( 'Left', 'pets' ),
				'center' => esc_html__( 'Center', 'pets' ),
				'right'  => esc_html__( 'Right', 'pets' ),
			),
			'std'        => 'left',
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'pets' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'pets' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'pets' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'pets' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '40px',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'pets' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'pets' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'pets' ),
			'sub_desc'   => esc_html__( 'Select border', 'pets' ),
			'dependency' => $post_title_dependency,
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'pets' ),
			'std'        => array(
				'preview-text'  => 'Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Muli',
				'font-weight'   => '700',
				'font-size'     => '22px',
				'color'         => '#566073',
				'css-selectors' => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => $post_title_dependency,
		) : null,

		// Author Info.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'author_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Author Meta Info', 'pets' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'show_author_meta_info_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Author Meta Info', 'pets' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide Author Meta Info.', 'pets' ),
			'std'      => '1',
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'author_meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Author Meta Info Font', 'pets' ),
			'std'   => array(
				'preview-text'  => 'Author Meta Info',
				'preview-color' => 'light',
				'font-family'   => 'Muli',
				'font-weight'   => '700',
				'font-size'     => '18px',
				'color'         => '#566073',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .author-meta-info, .layout-' . $unique_id . ' .latestPost .author-meta-info a',
			),
		) : null,

		// Meta info.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'pets' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'pets' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'pets' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
					'time'    => array(
						'label'     => __( 'Reading Time', 'pets' ),
						'subfields' => array(
							array(
								'id'       => 'mts_meta_info_time_icon_' . $unique_id,
								'type'     => 'icon_select',
								'title'    => esc_html__( 'Select Icon', 'pets' ),
								// translators: link to plugin.
								'sub_desc' => sprintf( wp_kses_post( __( 'Need Time to Read plugin for this option. <a href="%s">Click here</a> to install it.', 'pets' ) ), 'https://mythemeshop.com/plugins/wp-time-to-read/' ),
							),
						),
					),
				),
				'disabled' => array(
					'date'     => array(
						'label'     => esc_html__( 'Date', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
					'category' => array(
						'label'     => esc_html__( 'Categories', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
					'time'    => array(
						'label'     => __( 'Reading Time', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_time_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
				),
				'disabled' => array(
					'date'     => array(
						'label'     => esc_html__( 'Date', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
					'category' => array(
						'label'     => esc_html__( 'Categories', 'pets' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'pets' ),
							),
						),
					),
				),
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'meta_info_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'pets' ),
			'sub_desc' => esc_html__( 'Select border.', 'pets' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'pets' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Muli',
				'font-weight'    => '700',
				'font-size'      => '14px',
				'color'          => '#566073',
				'additional-css' => 'text-transform: uppercase; letter-spacing: 0.504px;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			),
		) : null,
		// Post Container.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'pets' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'pets' ),
			'sub_desc' => esc_html__( 'Select border', 'pets' ),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'pets' ),
			'sub_desc' => esc_html__( 'Post margin.', 'pets' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '0',
				'bottom' => '0',
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'pets' ),
			'sub_desc' => esc_html__( 'Post padding.', 'pets' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'pets' ),
			'std'   => array(
				'preview-text'  => 'Post Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Muli',
				'font-weight'   => '700',
				'font-size'     => '24px',
				'line-height'   => '28px',
				'color'         => '#566073',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'pets' ),
			'std'   => array(
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Muli',
				'font-weight'   => '300',
				'font-size'     => '16px',
				'line-height'   => '26px',
				'color'         => '#566073',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
		) : null,

	);
endforeach;
